**************
Mopidy-Podcast
**************

.. image:: https://img.shields.io/pypi/v/Mopidy-Podcast
    :target: https://pypi.org/project/Mopidy-Podcast/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/github/workflow/status/tkem/mopidy-podcast/CI
    :target: https://github.com/tkem/mopidy-podcast/actions
    :alt: CI build status

.. image:: https://img.shields.io/readthedocs/mopidy-podcast
    :target: https://mopidy-podcast.readthedocs.io/
    :alt: Read the Docs build status

.. image:: https://img.shields.io/codecov/c/gh/tkem/mopidy-podcast
    :target: https://codecov.io/gh/tkem/mopidy-podcast
    :alt: Test coverage

.. image:: https://img.shields.io/github/license/tkem/mopidy-podcast
   :target: https://raw.github.com/tkem/mopidy-podcast/master/LICENSE
   :alt: License

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code style: black

Mopidy-Podcast is a Mopidy_ extension for browsing and playing
podcasts.

This extension lets you browse podcasts distributed as RSS feeds and
play individual episodes in a variety of audio formats.  Podcasts are
mapped to albums, while podcast episodes are shown as tracks in
Mopidy, with metadata converted to Mopidy’s native data model where
applicable.  OPML 2.0 subscription lists and directories are also
supported for multi-level browsing.

For more information and installation instructions, please see
Mopidy-Podcast's online documentation_.

.. _Mopidy: http://www.mopidy.com/
.. _Documentation: http://mopidy-podcast.readthedocs.io/en/latest/


Project Resources
=================

- `Source code <https://github.com/tkem/mopidy-podcast>`_
- `Issue tracker <https://github.com/tkem/mopidy-podcast/issues>`_
- `Changelog <https://github.com/tkem/mopidy-podcast/blob/master/CHANGELOG.rst>`_


Credits
=======  

- Original author: `Thomas Kemmer <https://github.com/tkem>`__
- Current maintainer: `Thomas Kemmer <https://github.com/tkem>`__
- `Contributors <https://github.com/tkem/mopidy-podcast/graphs/contributors>`_
